dd-delaunay
This is a library for computing the Delaunay triangulation of a set of n-dimensional points in a simplicial complex inspired by CGAL.
Features
- d-dimensional Delaunay triangulations
- Arbitrary data types associated with vertices and cells
- Serialization/Deserialization with serde
Modules
- delaunay_
core - The main module of the library. This module contains the public interface for the library.